@@ -16,4 +16,9 @@ extern "C" {
                                 keyData: CFDataRef,
                                 error: *mut CFErrorRef)
                                 -> SecKeyRef;
+
+    #[cfg(feature = "OSX_10_12")]
+    pub fn SecKeyCopyExternalRepresentation(key: SecKeyRef,
+                                            error: *mut CFErrorRef)
+                                            -> CFDataRef;
 }
